==> estateplat-common-1.2.3-20180930.022011-198-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtMjcycl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-06-13
 * @description 面积差异处理历史表(第五章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_mjcycl")
public class FcjyXjspfBaMmhtMjcycl extends FcjyXjspfBaParent {
    private String clid;//主键
    private String htid;//合同ID
    private String clfs;//处理方式
    private Double tnjzmjjflx;//按套内建筑面积给付利息(百分之)
    private String sfzxyd;//双方自行约定
    private String zxydnr;//自行约定内容
    private Double jzmjjflx;//建筑面积给付利息(百分之)

    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getClfs() {
        return clfs;
    }

    public void setClfs(String clfs) {
        this.clfs = clfs;
    }

    public Double getTnjzmjjflx() {
        return tnjzmjjflx;
    }

    public void setTnjzmjjflx(Double tnjzmjjflx) {
        this.tnjzmjjflx = tnjzmjjflx;
    }

    public String getSfzxyd() {
        return sfzxyd;
    }

    public void setSfzxyd(String sfzxyd) {
        this.sfzxyd = sfzxyd;
    }

    public String getZxydnr() {
        return zxydnr;
    }

    public void setZxydnr(String zxydnr) {
        this.zxydnr = zxydnr;
    }

    public Double getJzmjjflx() {
        return jzmjjflx;
    }

    public void setJzmjjflx(Double jzmjjflx) {
        this.jzmjjflx = jzmjjflx;
    }
}

==> estateplat-common-1.2.4-20191105.011705-174-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtMjcycl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-06-13
 * @description 面积差异处理历史表(第五章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_mjcycl")
public class FcjyXjspfBaMmhtMjcycl extends FcjyXjspfBaParent {
    private String clid;//主键
    private String htid;//合同ID
    private String clfs;//处理方式
    private String tnjzmjjflx;//按套内建筑面积给付利息(百分之)
    private String sfzxyd;//双方自行约定
    private String zxydnr;//自行约定内容
    private String jzmjjflx;//建筑面积给付利息(百分之)

    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getClfs() {
        return clfs;
    }

    public void setClfs(String clfs) {
        this.clfs = clfs;
    }

    public String getTnjzmjjflx() {
        return tnjzmjjflx;
    }

    public void setTnjzmjjflx(String tnjzmjjflx) {
        this.tnjzmjjflx = tnjzmjjflx;
    }

    public String getSfzxyd() {
        return sfzxyd;
    }

    public void setSfzxyd(String sfzxyd) {
        this.sfzxyd = sfzxyd;
    }

    public String getZxydnr() {
        return zxydnr;
    }

    public void setZxydnr(String zxydnr) {
        this.zxydnr = zxydnr;
    }

    public String getJzmjjflx() {
        return jzmjjflx;
    }

    public void setJzmjjflx(String jzmjjflx) {
        this.jzmjjflx = jzmjjflx;
    }
}
